import numpy as np


def get_status(data, fs):
    data = np.array(data[-fs * 4:]) # 取最新的4秒，因为传进来的可能会是12秒的数据
    count_4095 = data.count(4095)
    count_0 = data.count(0)
    if count_0 > 5 or count_4095 > 5:
        return 2

    # 用最新的4秒判断是否离床
    segf_old = np.array(data)
    segf_mean = np.mean(segf_old)  # 平均值
    segf_old = segf_old - segf_mean  # 原始值减去平均值
    segf_old = np.abs(segf_old)
    std = np.median(segf_old)  # 中位数

    if std <= 25 and (300 < segf_mean < 3800):
        return 0  # 无人
    else:
        return 1  # 有人



from setuptools import setup, find_packages

import re


def get_version(filepath):
    # 读取当前文件内容
    with open(filepath, 'r') as file:
        content = file.read()

    # 使用正则表达式查找当前版本号
    match = re.search(r"__version__ = '(\d+\.\d+)'", content)
    if match:
        current_version = float(match.group(1))
        print(f"Version updated to {current_version}")
        return current_version
    else:
        print("Version number not found in the file.")


# 替换为你的文件路径
version = get_version('hebo_tools/version.py')

setup(
    name='hebo_tools',               # 包名称
    version=version,                   # 版本号
    packages=find_packages(),        # 自动查找包
    description='用于离床判断',
    author='hy',
    author_email='yue.huang@slaaplekker.cn',
    url='https://github.com/yourname/my_package',  # 代码仓库URL
)



# logging_config.py
import logging
from logging.handlers import RotatingFileHandler

# 配置日志格式
LOG_FORMAT = '%(name)s %(asctime)s %(levelname)s %(filename)s %(lineno)s: %(message)s'
formatter = logging.Formatter(LOG_FORMAT)

# 创建 logger
logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

# 文件处理器配置
file_handler = RotatingFileHandler(filename='app.log', maxBytes=10 * 1024 * 1024, backupCount=1)
file_handler.setLevel(logging.DEBUG)
file_handler.setFormatter(formatter)

# 控制台处理器配置
console_handler = logging.StreamHandler()
console_handler.setLevel(logging.INFO)
console_handler.setFormatter(formatter)

# 添加处理器到 logger
logger.addHandler(console_handler)
logger.addHandler(file_handler)
